tools: increase polling timeout by 5 minutes

This is needed for 64 MiB images.

Signed-off-by: Benjamin Fair <benjaminfair@google.com>
Change-Id: I3e2a63d1c8ae5db956ca8d5553c98d9cc671409c
diff --git a/tools/helper.cpp b/tools/helper.cpp
index d3fef48..01a3c79 100644
--- a/tools/helper.cpp
+++ b/tools/helper.cpp
@@ -38,12 +38,12 @@
 
     try
     {
         /* sleep for 5 seconds and check 65 times, for a timeout of: 325
          * seconds.
          * TODO: make this command line configurable and provide smaller
          * default value.
          */
-        static constexpr int commandAttempts = 65;
+        static constexpr int commandAttempts = 125;
         int attempts = 0;
         bool exitLoop = false;
@@ -38,12 +38,12 @@
     try
     {
-        /* sleep for 5 seconds and check 65 times, for a timeout of: 325
+        /* sleep for 5 seconds and check 125 times, for a timeout of: 625
          * seconds.
          * TODO: make this command line configurable and provide smaller